@@ -3,7 +3,7 @@ to TCP object"""
 __author__ = "Matt Baker"
 __credits__ = ["Matt Baker"]
 __license__ = "GPL"
-__version__ = "1.0.6"
+__version__ = "1.0.8"
 __maintainer__ = "Matt Baker"
 __email__ = "mbakervtech@gmail.com"
 __status__ = "Development"
@@ -151,6 +151,7 @@ class TCP:
         nop (No-op) bytes to fit in 32 bit word
 
         TODO handle sack value
+
         :return: tuple consisting of bytes of options for this TCP segment and increase to options header
         :rtype: tuple of bytes
         """
@@ -239,6 +240,7 @@ class TCP:
         """
         Converts TCP to proper format of payload bytes to send
         self.payload is converted to bytes with str.encode(self.payload)
+
         :return: bytes representation of TCP
         :rtype: bytes
         """
@@ -296,9 +298,11 @@ class TCP:
         return pack('!HHIIBBHHH', self.src_prt, self.dst_prt, self.sqn, self.ack_num, offset, flags, self.window, self.checksum, self.urg_pnt) + options[0] + payload
 
 
-    def parse_options(self, option_bytes):
+    @classmethod
+    def parse_options(cls, option_bytes):
         """
         Parses TCP header options from a series of byte
+
         :param option_bytes: series of bytes containing TCP Header options
         :type option_bytes: bytes
         :return: list of options to return containing [MSS, Window Scale, \
@@ -353,6 +357,7 @@ class TCP:
     def tcp_parser(cls, data, recursive=True):
         """
         Class method that creates TCP object
+
         :param data: TCP segment passed in as bytes
         :type param: bytes
         :return: TCP object created from values in data
@@ -408,6 +413,7 @@ class TCP:
         """
         Method that parses higher layers and sets the payload of calling TCP
         object
+
         :param recursive: boolean value of whether parsing function should \
             be called recursively through all layers
         :type recursive: true
@@ -429,13 +435,14 @@ class TCP:
     def __str__(self):
         """
         Create string representation of TCP object
+
         :return: string of TCP
         :rtype: String
         """
-        header = "*" * 20 + "_UDP_" + "*" * 20
+        header = "*" * 20 + "_TCP_" + "*" * 20
         src = "Source: " + str(self.src_prt)
         dst = "Destination: "  + str(self.dst_prt)
-        length = "Length: " + str(self.length)
+        offset = "Data Offset: " + str(self.offset) + " 32 bit words"
         sqn = "Sequence: " + str(self.sqn)
         ack_num = "Acknowledgment: " + str(self.ack_num)
         flags = "Flags: "
@@ -447,12 +454,11 @@ class TCP:
         syn = "Syn: " + str(self.syn)
         fin = "Fin: " + str(self.fin)
         window = "Window: "  + str(self.window)
-        offset = "Data Offset: " + str(self.offset) + " 32 bit words"
         urg_pnt = "Urgent Pointer: " + str(self.urg_pnt)
 
         trailer = "*" * 45
 
-        return "\n".join((header, src, dst, length, sqn, ack_num, flags, 
+        return "\n".join((header, src, dst, sqn, ack_num, flags, 
             separator, urg, ack, psh, rst, syn, fin, separator, window, offset,
             urg_pnt, trailer))
 
